@@ -109,7 +109,7 @@ def download(url, fpath=None, dpath=None, fname=None, hash_prefix=None,
         >>> fpath = download(url, hasher='sha1', hash_prefix='f79ea24571da6ddd2ba12e3d57b515249ecb8a35')
         Downloading url='http://i.imgur.com/rqwaDag.png' to fpath=...rqwaDag.png
         ...
-        ...1233/1233... rate=... Hz, eta=..., total=..., wall=...
+        ...1233/1233... rate=... Hz, eta=..., total=...
 
     Example:
         >>> # xdoctest: +REQUIRES(--network)
